@@ -1,6 +1,8 @@
+'use strict';
+
 var bower = require('bower');
 var util = require('./utils.js');
-var spawn = require('child_process').spawn;
+var shelljs = require('shelljs');
 
 module.exports = function(grunt) {
 
@@ -34,21 +36,11 @@ module.exports = function(grunt) {
   });
 
 
-  grunt.registerMultiTask('docs', 'create angular docs', function(){
-    var done = this.async();
-    var files = this.data;
-    var docs  = spawn('node', ['docs/src/gen-docs.js']);
-    docs.stdout.pipe(process.stdout);
-    docs.stderr.pipe(process.stderr);
-    docs.on('exit', function(code){
-      if(code !== 0) grunt.fail.warn('Error creating docs');
-      grunt.file.expand(files).forEach(function(file){
-        var content = util.process(grunt.file.read(file), grunt.config('NG_VERSION'), false);
-        grunt.file.write(file, content);
-      });
-      grunt.log.ok('docs created');
-      done();
-    });
+  grunt.registerTask('docs', 'create angular docs', function(){
+    var gruntProc = shelljs.exec('"node_modules/.bin/gulp" --gulpfile docs/gulpfile.js');
+    if (gruntProc.code !== 0) {
+      throw new Error('doc generation failed');
+    }
   });
 
 
