@@ -110,6 +110,7 @@ describe('injector', function() {
 
 
     function fn(a, b, c, d) {
+      /* jshint -W040 */
       args = [this, a, b, c, d];
       return a + b + c + d;
     }
@@ -147,6 +148,7 @@ describe('injector', function() {
 
 
   describe('annotation', function() {
+    /* global annotate: false */
     it('should return $inject', function() {
       function fn() {}
       fn.$inject = ['a'];
@@ -159,11 +161,12 @@ describe('injector', function() {
 
 
     it('should create $inject', function() {
+      var extraParans = angular.noop;
       // keep the multi-line to make sure we can handle it
       function $f_n0 /*
           */(
           $a, // x, <-- looks like an arg but it is a comment
-          b_ , /* z, <-- looks like an arg but it is a
+          b_, /* z, <-- looks like an arg but it is a
                  multi-line comment
                  function (a, b) {}
                  */
@@ -175,7 +178,7 @@ describe('injector', function() {
 
 
     it('should strip leading and trailing underscores from arg name during inference', function() {
-      function beforeEachFn(_foo_) { /* foo = _foo_ */ };
+      function beforeEachFn(_foo_) { /* foo = _foo_ */ }
       expect(annotate(beforeEachFn)).toEqual(['foo']);
     });
 
@@ -239,10 +242,9 @@ describe('injector', function() {
 
   describe('module', function() {
     it('should provide $injector even when no module is requested', function() {
-      var $provide,
-          $injector = createInjector([
-            angular.extend(function(p) { $provide = p; }, {$inject: ['$provide']})
-          ]);
+      var $provide, $injector = createInjector([
+        angular.extend(function(p) { $provide = p; }, {$inject: ['$provide']})
+      ]);
       expect($injector.get('$injector')).toBe($injector);
     });
 
@@ -293,14 +295,37 @@ describe('injector', function() {
       expect(log).toEqual('abc');
     });
 
+    it('should load different instances of dependent functions', function() {
+      function  generateValueModule(name, value) {
+        return function ($provide) {
+          $provide.value(name, value);
+        };
+      }
+      var injector = createInjector([generateValueModule('name1', 'value1'),
+                                     generateValueModule('name2', 'value2')]);
+      expect(injector.get('name2')).toBe('value2');
+    });
+
+    it('should load same instance of dependent function only once', function() {
+      var count = 0;
+      function valueModule($provide) {
+        count++;
+        $provide.value('name', 'value');
+      }
+
+      var injector = createInjector([valueModule, valueModule]);
+      expect(injector.get('name')).toBe('value');
+      expect(count).toBe(1);
+    });
+
     it('should execute runBlocks after injector creation', function() {
       var log = '';
       angular.module('a', [], function(){ log += 'a'; }).run(function() { log += 'A'; });
       angular.module('b', ['a'], function(){ log += 'b'; }).run(function() { log += 'B'; });
       createInjector([
-          'b',
-          valueFn(function() { log += 'C'; }),
-          [valueFn(function() { log += 'D'; })]
+        'b',
+        valueFn(function() { log += 'C'; }),
+        [valueFn(function() { log += 'D'; })]
       ]);
       expect(log).toEqual('abABCD');
     });
@@ -328,19 +353,19 @@ describe('injector', function() {
         it('should create configuration injectable constants', function() {
           var log = [];
           createInjector([
-              function($provide){
-                $provide.constant('abc', 123);
-                $provide.constant({a: 'A', b:'B'});
-                return function(a) {
-                  log.push(a);
-                }
-              },
-              function(abc) {
-                log.push(abc);
-                return function(b) {
-                  log.push(b);
-                }
-              }
+            function($provide){
+              $provide.constant('abc', 123);
+              $provide.constant({a: 'A', b:'B'});
+              return function(a) {
+                log.push(a);
+              };
+            },
+            function(abc) {
+              log.push(abc);
+              return function(b) {
+                log.push(b);
+              };
+            }
           ]).get('abc');
           expect(log).toEqual([123, 'A', 'B']);
         });
@@ -422,7 +447,7 @@ describe('injector', function() {
 
 
         it('should configure $provide provider type', function() {
-          function Type() {};
+          function Type() {}
           Type.prototype.$get = function() {
             expect(this instanceof Type).toBe(true);
             return 'abc';
@@ -436,7 +461,7 @@ describe('injector', function() {
         it('should configure $provide using an array', function() {
           function Type(PREFIX) {
             this.prefix = PREFIX;
-          };
+          }
           Type.prototype.$get = function() {
             return this.prefix + 'def';
           };
@@ -527,7 +552,7 @@ describe('injector', function() {
               return function(val) {
                 log.push('myService:' + val + ',' + dep1);
                 return 'origReturn';
-              }
+              };
             }]);
 
             $provide.decorator('myService', function($delegate) {
@@ -554,7 +579,7 @@ describe('injector', function() {
               return function(val) {
                 log.push('myService:' + val);
                 return 'origReturn';
-              }
+              };
             });
 
             $provide.decorator('myService', function($delegate, dep1) {
@@ -630,7 +655,7 @@ describe('injector', function() {
             $provide.factory('service', function(service){});
             return function(service) {};
           }]);
-        }).toThrowMinErr('$injector', 'cdep', 'Circular dependency found: service');
+        }).toThrowMinErr('$injector', 'cdep', 'Circular dependency found: service <- service');
       });
 
 
@@ -641,7 +666,7 @@ describe('injector', function() {
             $provide.factory('b', function(a){});
             return function(a) {};
           }]);
-        }).toThrowMinErr('$injector', 'cdep', 'Circular dependency found: b <- a');
+        }).toThrowMinErr('$injector', 'cdep', 'Circular dependency found: a <- b <- a');
       });
 
     });
@@ -704,7 +729,8 @@ describe('injector', function() {
       })).toEqual('melville:moby');
       expect($injector.invoke(function(book, author) {
         expect(this).toEqual($injector);
-        return author + ':' + book;}, $injector)).toEqual('melville:moby');
+        return author + ':' + book;
+      }, $injector)).toEqual('melville:moby');
     });
 
 
@@ -722,7 +748,7 @@ describe('injector', function() {
 
     it('should invoke method which is annotated', function() {
       expect($injector.invoke(extend(function(b, a) {
-        return a + ':' + b
+        return a + ':' + b;
       }, {$inject:['book', 'author']}))).toEqual('melville:moby');
       expect($injector.invoke(extend(function(b, a) {
         expect(this).toEqual($injector);
@@ -855,10 +881,10 @@ describe('injector', function() {
 
 
     it('should prevent instance lookup in module', function() {
-      function instanceLookupInModule(name) { throw Error('FAIL'); }
+      function instanceLookupInModule(name) { throw new Error('FAIL'); }
       expect(function() {
         createInjector([function($provide) {
-          $provide.value('name', 'angular')
+          $provide.value('name', 'angular');
         }, instanceLookupInModule]);
       }).toThrowMatching(/\[\$injector:unpr] Unknown provider: name/);
     });
