@@ -378,6 +378,39 @@ describe('select', function() {
           expect(element).toEqualSelect(['? string:r2d2 ?']);
           expect(scope.robot).toBe('r2d2');
         });
+
+        describe('selectController.hasOption', function() {
+          it('should return true for options added via ngOptions', function() {
+            scope.robots = [
+              {key: 1, value: 'c3p0'},
+              {key: 2, value: 'r2d2'}
+            ];
+            scope.robot = 'r2d2';
+
+            compile('<select ng-model="robot" ' +
+                      'ng-options="item.key as item.value for item in robots">' +
+                    '</select>');
+
+            var selectCtrl = element.data().$selectController;
+
+            expect(selectCtrl.hasOption('c3p0')).toBe(true);
+            expect(selectCtrl.hasOption('r2d2')).toBe(true);
+
+            scope.$apply(function() {
+              scope.robots.pop();
+            });
+
+            expect(selectCtrl.hasOption('c3p0')).toBe(true);
+            expect(selectCtrl.hasOption('r2d2')).toBe(false);
+
+            scope.$apply(function() {
+              scope.robots.push({key: 2, value: 'r2d2'});
+            });
+
+            expect(selectCtrl.hasOption('c3p0')).toBe(true);
+            expect(selectCtrl.hasOption('r2d2')).toBe(true);
+          });
+        });
       });
     });
   });
@@ -454,6 +487,39 @@ describe('select', function() {
       expect(element).toBeValid();
       expect(element).toBeDirty();
     });
+
+    describe('selectController.hasOption', function() {
+      it('should return true for options added via ngOptions', function() {
+        scope.robots = [
+          {key: 1, value: 'c3p0'},
+          {key: 2, value: 'r2d2'}
+        ];
+        scope.robot = 'r2d2';
+
+        compile('<select ng-model="robot" multiple ' +
+                  'ng-options="item.key as item.value for item in robots">' +
+                '</select>');
+
+        var selectCtrl = element.data().$selectController;
+
+        expect(selectCtrl.hasOption('c3p0')).toBe(true);
+        expect(selectCtrl.hasOption('r2d2')).toBe(true);
+
+        scope.$apply(function() {
+          scope.robots.pop();
+        });
+
+        expect(selectCtrl.hasOption('c3p0')).toBe(true);
+        expect(selectCtrl.hasOption('r2d2')).toBe(false);
+
+        scope.$apply(function() {
+          scope.robots.push({key: 2, value: 'r2d2'});
+        });
+
+        expect(selectCtrl.hasOption('c3p0')).toBe(true);
+        expect(selectCtrl.hasOption('r2d2')).toBe(true);
+      });
+    });
   });
 
 
@@ -871,6 +937,26 @@ describe('select', function() {
         expect(element.val()).toEqual('1');
       });
 
+      it('should update options in the DOM', function() {
+        compile(
+          '<select ng-model="selected" ng-options="item.id as item.name for item in values"></select>'
+        );
+
+        scope.$apply(function() {
+          scope.values = [{id: 10, name: 'A'}, {id: 20, name: 'B'}];
+          scope.selected = scope.values[0].id;
+        });
+
+        scope.$apply(function() {
+          scope.values[0].name = 'C';
+        });
+
+        var options = element.find('option');
+        expect(options.length).toEqual(2);
+        expect(sortedHtml(options[0])).toEqual('<option value="0">C</option>');
+        expect(sortedHtml(options[1])).toEqual('<option value="1">B</option>');
+      });
+
 
       it('should bind to object key', function() {
         createSelect({
