@@ -9,12 +9,12 @@ describe('$http', function() {
   });
 
   beforeEach(module(function($exceptionHandlerProvider) {
-      $exceptionHandlerProvider.mode('log');
+    $exceptionHandlerProvider.mode('log');
   }));
 
   afterEach(inject(function($exceptionHandler, $httpBackend, $rootScope) {
     forEach($exceptionHandler.errors, function(e) {
-      dump('Unhandled exception: ', e)
+      dump('Unhandled exception: ', e);
     });
 
     if ($exceptionHandler.errors.length) {
@@ -28,7 +28,7 @@ describe('$http', function() {
 
   describe('$httpProvider', function() {
     describe('interceptors', function() {
-     it('should accept injected rejected response interceptor', function() {
+      it('should accept injected rejected response interceptor', function() {
         var wasCalled = false;
         module(function($httpProvider, $provide) {
           $httpProvider.responseInterceptors.push('injectedInterceptor');
@@ -83,7 +83,7 @@ describe('$http', function() {
             return {
               response: function(response) {
                 response.data += ':1';
-                savedResponse = response
+                savedResponse = response;
                 return $q.reject(':2');
               }
             };
@@ -194,7 +194,7 @@ describe('$http', function() {
                 response.data += '!';
                 return response;
               });
-            }
+            };
           });
 
           // return a new resolved promise representing modified response object
@@ -221,7 +221,7 @@ describe('$http', function() {
                 response.data = uppercase(response.data);
                 return response;
               });
-            }
+            };
           });
           $httpProvider.responseInterceptors.push('myInterceptor');
         });
@@ -344,7 +344,7 @@ describe('$http', function() {
           $rootScope.$apply();
           expect(config.method).toEqual('get');
           expect(config.url).toEqual('/url');
-          expect(config.headers.foo).toEqual('bar')
+          expect(config.headers.foo).toEqual('bar');
         });
       });
 
@@ -442,8 +442,8 @@ describe('$http', function() {
 
 
       it('should expand arrays in params map', inject(function($httpBackend, $http) {
-          $httpBackend.expect('GET', '/url?a=1&a=2&a=3').respond('');
-          $http({url: '/url', params: {a: [1,2,3]}, method: 'GET'});
+        $httpBackend.expect('GET', '/url?a=1&a=2&a=3').respond('');
+        $http({url: '/url', params: {a: [1,2,3]}, method: 'GET'});
       }));
 
 
@@ -460,7 +460,13 @@ describe('$http', function() {
       it('should not add question mark when params is empty', function() {
         $httpBackend.expect('GET', '/url').respond('');
         $http({url: '/url', params: {}, method: 'GET'});
-      })
+      });
+
+      it('should not double quote dates', function() {
+        if (msie < 9) return;
+        $httpBackend.expect('GET', '/url?date=2014-07-15T17:30:00.000Z').respond('');
+        $http({url: '/url', params: {date:new Date('2014-07-15T17:30:00.000Z')}, method: 'GET'});
+      });
     });
 
 
@@ -591,7 +597,7 @@ describe('$http', function() {
           expect(r.headers('nothing')).toBe(null);
         });
 
-        $http({url: '/url', method: 'GET'}).then(callback)
+        $http({url: '/url', method: 'GET'}).then(callback);
         $httpBackend.flush();
 
         expect(callback).toHaveBeenCalledOnce();
@@ -629,6 +635,7 @@ describe('$http', function() {
 
 
     describe('response headers parser', function() {
+      /* global parseHeaders: false */
 
       it('should parse basic', function() {
         var parsed = parseHeaders(
@@ -771,6 +778,18 @@ describe('$http', function() {
         $httpBackend.flush();
       });
 
+      it('should delete default headers if custom header function returns null', function () {
+
+        $httpBackend.expect('POST', '/url', 'messageBody', function(headers) {
+          return !('Accept' in headers);
+        }).respond('');
+
+        $http({url: '/url', method: 'POST', data: 'messageBody', headers: {
+          'Accept': function() { return null; }
+        }});
+        $httpBackend.flush();
+      });
+
       it('should override default headers with custom in a case insensitive manner', function() {
         $httpBackend.expect('POST', '/url', 'messageBody', function(headers) {
           return headers['accept'] == 'Rewritten' &&
@@ -812,6 +831,22 @@ describe('$http', function() {
         $httpBackend.flush();
       });
 
+      it('should NOT delete Content-Type header if request data/body is set by request transform', function() {
+        $httpBackend.expect('POST', '/url', {'one' : 'two'}, function(headers) {
+          return headers['Content-Type'] == 'application/json;charset=utf-8';
+        }).respond('');
+
+        $http({
+          url: '/url',
+          method: 'POST',
+          transformRequest : function(data) {
+            data = {'one' : 'two'};
+            return data;
+          }
+        });
+
+        $httpBackend.flush();
+      });
 
       it('should set the XSRF cookie into a XSRF header', inject(function($browser) {
         function checkXSRF(secret, header) {
@@ -833,8 +868,8 @@ describe('$http', function() {
         $http({url: '/url', method: 'POST', headers: {'S-ome': 'Header'}});
         $http({url: '/url', method: 'PUT', headers: {'Another': 'Header'}});
         $http({url: '/url', method: 'DELETE', headers: {}});
-        $http({url: '/url', method: 'GET', xsrfHeaderName: 'aHeader'})
-        $http({url: '/url', method: 'GET', xsrfCookieName: 'aCookie'})
+        $http({url: '/url', method: 'GET', xsrfHeaderName: 'aHeader'});
+        $http({url: '/url', method: 'GET', xsrfCookieName: 'aCookie'});
 
         $httpBackend.flush();
       }));
@@ -860,6 +895,25 @@ describe('$http', function() {
 
         $httpBackend.flush();
       }));
+
+      it('should check the cache before checking the XSRF cookie', inject(function($browser, $cacheFactory) {
+        var testCache = $cacheFactory('testCache'),
+            executionOrder = [];
+
+        spyOn($browser, 'cookies').andCallFake(function() {
+          executionOrder.push('cookies');
+          return {'XSRF-TOKEN':'foo'};
+        });
+        spyOn(testCache, 'get').andCallFake(function() {
+          executionOrder.push('cache');
+        });
+
+        $httpBackend.expect('GET', '/url', undefined).respond('');
+        $http({url: '/url', method: 'GET', cache: testCache});
+        $httpBackend.flush();
+
+        expect(executionOrder).toEqual(['cache', 'cookies']);
+      }));
     });
 
 
@@ -1038,8 +1092,8 @@ describe('$http', function() {
 
 
         it('should pipeline more functions', function() {
-          function first(d, h) {return d + '-first' + ':' + h('h1')}
-          function second(d) {return uppercase(d)}
+          function first(d, h) {return d + '-first' + ':' + h('h1');}
+          function second(d) {return uppercase(d);}
 
           $httpBackend.expect('POST', '/url', 'REQ-FIRST:V1').respond(200);
           $http.post('/url', 'req', {
@@ -1123,8 +1177,8 @@ describe('$http', function() {
 
 
         it('should pipeline more functions', function() {
-          function first(d, h) {return d + '-first' + ':' + h('h1')}
-          function second(d) {return uppercase(d)}
+          function first(d, h) {return d + '-first' + ':' + h('h1');}
+          function second(d) {return uppercase(d);}
 
           $httpBackend.expect('POST', '/url').respond(200, 'resp', {h1: 'v1'});
           $http.post('/url', '', {transformResponse: [first, second]}).success(callback);
@@ -1163,6 +1217,18 @@ describe('$http', function() {
         expect(callback.mostRecentCall.args[0]).toBe('content');
       }));
 
+      it('should cache JSONP request when cache is provided', inject(function($rootScope) {
+        $httpBackend.expect('JSONP', '/url?cb=JSON_CALLBACK').respond('content');
+        $http({method: 'JSONP', url: '/url?cb=JSON_CALLBACK', cache: cache});
+        $httpBackend.flush();
+
+        $http({method: 'JSONP', url: '/url?cb=JSON_CALLBACK', cache: cache}).success(callback);
+        $rootScope.$digest();
+
+        expect(callback).toHaveBeenCalledOnce();
+        expect(callback.mostRecentCall.args[0]).toBe('content');
+      }));
+
       it('should cache request when cache is provided and no method specified', function () {
         doFirstCacheRequest();
 
@@ -1333,7 +1399,7 @@ describe('$http', function() {
       describe('$http.defaults.cache', function () {
 
         it('should be undefined by default', function() {
-          expect($http.defaults.cache).toBeUndefined()
+          expect($http.defaults.cache).toBeUndefined();
         });
 
         it('should cache requests when no cache given in request config', function() {
@@ -1427,6 +1493,20 @@ describe('$http', function() {
         $httpBackend.verifyNoOutstandingExpectation();
         $httpBackend.verifyNoOutstandingRequest();
       }));
+
+
+      it('should reject promise when timeout promise resolves', inject(function($timeout) {
+        var onFulfilled = jasmine.createSpy('onFulfilled');
+        var onRejected = jasmine.createSpy('onRejected');
+        $httpBackend.expect('GET', '/some').respond(200);
+
+        $http({method: 'GET', url: '/some', timeout: $timeout(noop, 10)}).then(onFulfilled, onRejected);
+
+        $timeout.flush(100);
+
+        expect(onFulfilled).not.toHaveBeenCalled();
+        expect(onRejected).toHaveBeenCalledOnce();
+      }));
     });
 
 
@@ -1497,7 +1577,7 @@ describe('$http', function() {
         expect($http.defaults.headers.post).not.toBe($http.defaults.headers.put);
         expect($http.defaults.headers.post).not.toBe($http.defaults.headers.patch);
         expect($http.defaults.headers.put).not.toBe($http.defaults.headers.patch);
-      })
+      });
     });
   });
 
@@ -1517,7 +1597,11 @@ describe('$http', function() {
 
     inject(function($http, $rootScope) {
       $http({
-        method: 'GET', url: 'some.html', timeout: 12345, withCredentials: true, responseType: 'json'
+        method: 'GET',
+        url: 'some.html',
+        timeout: 12345,
+        withCredentials: true,
+        responseType: 'json'
       });
       $rootScope.$digest();
       expect($httpBackend).toHaveBeenCalledOnce();
@@ -1541,7 +1625,10 @@ describe('$http', function() {
     inject(function($http, $rootScope) {
       $http.defaults.withCredentials = true;
       $http({
-        method: 'GET', url: 'some.html', timeout: 12345, responseType: 'json'
+        method: 'GET',
+        url: 'some.html',
+        timeout: 12345,
+        responseType: 'json'
       });
       $rootScope.$digest();
       expect($httpBackend).toHaveBeenCalledOnce();
