@@ -87,6 +87,19 @@ describe('$location', function() {
       expect(url.absUrl()).toBe('http://www.domain.com:9877/new/path?search=a&b=c&d#hash');
     });
 
+    it('path() should not break on numeric values', function() {
+      url.path(1);
+      expect(url.path()).toBe('/1');
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/1?search=a&b=c&d#hash');
+    });
+
+
+    it('path() should set to empty path on null value', function () {
+      url.path('/foo');
+      expect(url.path()).toBe('/foo');
+      url.path(null);
+      expect(url.path()).toBe('/');
+    });
 
     it('search() should accept string', function() {
       url.search('x=y&c');
@@ -127,6 +140,13 @@ describe('$location', function() {
     });
 
 
+    it('search() should accept numeric keys', function() {
+      url.search({1: 'one', 2: 'two'});
+      expect(url.search()).toEqual({'1': 'one', '2': 'two'});
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/path/b?1=one&2=two#hash');
+    });
+
+
     it('search() should handle multiple value', function() {
       url.search('a&b');
       expect(url.search()).toEqual({a: true, b: true});
@@ -143,6 +163,8 @@ describe('$location', function() {
     it('search() should handle single value', function() {
       url.search('ignore');
       expect(url.search()).toEqual({ignore: true});
+      url.search(1);
+      expect(url.search()).toEqual({1: true});
     });
 
 
@@ -163,6 +185,20 @@ describe('$location', function() {
     });
 
 
+    it('hash() should accept numeric parameter', function() {
+      url.hash(5);
+      expect(url.hash()).toBe('5');
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/path/b?search=a&b=c&d#5');
+    });
+
+
+    it('hash() should accept null parameter', function() {
+      url.hash(null);
+      expect(url.hash()).toBe('');
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/path/b?search=a&b=c&d');
+    });
+
+
     it('url() should change the path, search and hash', function() {
       url.url('/some/path?a=b&c=d#hhh');
       expect(url.url()).toBe('/some/path?a=b&c=d#hhh');
