@@ -13,6 +13,7 @@ describe('Scope', function() {
 
 
     it('should expose the constructor', inject(function($rootScope) {
+      /* jshint -W103 */
       if (msie) return;
       expect($rootScope.__proto__).toBe($rootScope.constructor.prototype);
     }));
@@ -251,7 +252,7 @@ describe('Scope', function() {
 
       try {
         $rootScope.$digest();
-        throw Error('Should have thrown exception');
+        throw new Error('Should have thrown exception');
       } catch(e) {
         expect(e.message.match(/"fn: (watcherA|function)/g).length).toBe(10);
       }
@@ -260,27 +261,27 @@ describe('Scope', function() {
 
     it('should prevent infinite loop when creating and resolving a promise in a watched expression', function() {
       module(function($rootScopeProvider) {
-          $rootScopeProvider.digestTtl(10);
+        $rootScopeProvider.digestTtl(10);
       });
       inject(function($rootScope, $q) {
-          var d = $q.defer();
+        var d = $q.defer();
 
-          d.resolve('Hello, world.');
-          $rootScope.$watch(function () {
-              var $d2 = $q.defer();
-              $d2.resolve('Goodbye.');
-              $d2.promise.then(function () { });
-              return d.promise;
-          }, function () { return 0; });
+        d.resolve('Hello, world.');
+        $rootScope.$watch(function () {
+          var $d2 = $q.defer();
+          $d2.resolve('Goodbye.');
+          $d2.promise.then(function () { });
+          return d.promise;
+        }, function () { return 0; });
 
-          expect(function() {
-              $rootScope.$digest();
-          }).toThrowMinErr('$rootScope', 'infdig', '10 $digest() iterations reached. Aborting!\n'+
-                  'Watchers fired in the last 5 iterations: []');
+        expect(function() {
+          $rootScope.$digest();
+        }).toThrowMinErr('$rootScope', 'infdig', '10 $digest() iterations reached. Aborting!\n'+
+                'Watchers fired in the last 5 iterations: []');
 
-          expect($rootScope.$$phase).toBeNull();
-      });
+        expect($rootScope.$$phase).toBeNull();
       });
+    });
 
 
     it('should not fire upon $watch registration on initial $digest', inject(function($rootScope) {
@@ -697,6 +698,14 @@ describe('Scope', function() {
           $rootScope.$digest();
           expect(log.empty()).toEqual([{newVal: {b: {}, c: 'B'}, oldVal: {a: [], b: {}, c: 'B'}}]);
         });
+
+        it('should not infinitely digest when current value is NaN', function() {
+          $rootScope.obj = {a: NaN};
+          expect(function() {
+            $rootScope.$digest();
+          }).not.toThrow();
+        });
+
       });
     });
 
@@ -748,7 +757,7 @@ describe('Scope', function() {
         $rootScope.$watch(log.fn('w4'), function() {
           log('w4action');
           $rootScope.$evalAsync(function() {
-            log('evalAsync')
+            log('evalAsync');
           });
         });
         $rootScope.$digest();
@@ -1067,7 +1076,8 @@ describe('Scope', function() {
       expect($rootScope.$$asyncQueue).toEqual([
         {scope: $rootScope, expression: 'rootExpression'},
         {scope: childScope, expression: 'childExpression'},
-        {scope: isolateScope, expression: 'isolateExpression'}]);
+        {scope: isolateScope, expression: 'isolateExpression'}
+      ]);
     }));
 
 
@@ -1247,9 +1257,11 @@ describe('Scope', function() {
           });
         });
 
-        expect(function() { childScope2.$apply(function() {
-          childScope2.x = 'something';
-        }); }).toThrowMinErr('$rootScope', 'inprog', '$digest already in progress');
+        expect(function() {
+          childScope2.$apply(function() {
+            childScope2.x = 'something';
+          });
+        }).toThrowMinErr('$rootScope', 'inprog', '$digest already in progress');
       }));
     });
   });
@@ -1668,7 +1680,7 @@ describe('Scope', function() {
       expect(scope.greeting).toEqual(undefined);
 
       scope.$watch('name', function() {
-       scope.greeting = scope.salutation + ' ' + scope.name + '!';
+        scope.greeting = scope.salutation + ' ' + scope.name + '!';
       }); // initialize the watch
 
       expect(scope.greeting).toEqual(undefined);
