@@ -1,3 +1,5 @@
+'use strict';
+
 describe('linky', function() {
   var linky;
 
@@ -23,12 +25,14 @@ describe('linky', function() {
                     toEqual('<a href="mailto:me@example.com">me@example.com</a>');
     expect(linky("send email to me@example.com, but")).
       toEqual('send email to <a href="mailto:me@example.com">me@example.com</a>, but');
+    expect(linky("my email is \"me@example.com\"")).
+      toEqual('my email is &#34;<a href="mailto:me@example.com">me@example.com</a>&#34;');
   });
 
   it('should handle target:', function() {
     expect(linky("http://example.com", "_blank")).
-      toEqual('<a target="_blank" href="http://example.com">http://example.com</a>')
+      toEqual('<a target="_blank" href="http://example.com">http://example.com</a>');
     expect(linky("http://example.com", "someNamedIFrame")).
-      toEqual('<a target="someNamedIFrame" href="http://example.com">http://example.com</a>')
+      toEqual('<a target="someNamedIFrame" href="http://example.com">http://example.com</a>');
   });
 });
